// src/index.ts
import { v4 } from "uuid";
import pluralize from "pluralize";
import crypto from "crypto";
import bytes from "bytes";
import moment from "moment";
import isEven from "is-even";
import isOdd from "is-odd";
import isNumber from "is-number";
var isTypescript = Symbol.for("ts-node.register.instance") in process;
var sha256 = (data) => {
  return crypto.createHash("sha256").update(stringify(data)).digest().toString("hex");
};
var md5 = (data) => {
  return crypto.createHash("md5").update(stringify(data)).digest().toString("hex");
};
var hex = (data) => {
  return Buffer.from(stringify(data)).toString("hex");
};
var base64 = (data) => {
  return Buffer.from(stringify(data)).toString("base64");
};
var binary = (data) => {
  return Buffer.from(stringify(data)).toString("binary");
};
var ascii = (data) => {
  return Buffer.from(stringify(data)).toString("ascii");
};
var latin1 = (data) => {
  return Buffer.from(stringify(data)).toString("latin1");
};
var decode = (data, encoding) => {
  return Buffer.from(data.toString(), encoding).toString("utf-8");
};
var plural = pluralize;
var capitalize = (str, eachword = false) => {
  if (!eachword) {
    const capitalletter = str.charAt(0).toUpperCase();
    return capitalletter + str.slice(1);
  } else {
    const words = str.split(/ +/g);
    const finalWords = [];
    for (const word of words) {
      const capitalletter = word.charAt(0).toUpperCase();
      finalWords.push(capitalletter + word.slice(1));
    }
    return finalWords.join(" ");
  }
};
var crop = (str, charNumber) => {
  return `${str.substring(0, charNumber - 3)}${str.length > charNumber ? "..." : ""}`;
};
var remove = (str, ...toRemove) => {
  let final = str;
  for (const text of toRemove) final = str.replace(text, "");
  return final;
};
var escape = (str) => {
  return str.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
};
var first = (array, n = 1) => {
  if (n === 1) return [array[0]];
  return array.filter((_, index) => index < n);
};
var last = (array, n = 1) => {
  if (n === 1) return [array.at(-1)];
  return array.filter((_, index) => array.length - index <= n);
};
var random = (array) => {
  return array[Math.floor(Math.random() * array.length)];
};
var get = (array, key) => {
  return array.map((element) => element[key]);
};
var groupBy = (array, key) => {
  return array.reduce((group2, element) => {
    const keyValue = element[key];
    return { ...group2, [keyValue]: [...group2[keyValue] ?? [], element] };
  }, {});
};
var group = (array, n) => {
  const g = [];
  for (let i = 0, j = 0; i < array.length; i++) {
    if (i >= n && i % n === 0) j++;
    g[j] = g[j] || [];
    g[j].push(array[i]);
  }
  return g;
};
var stringify = (arg) => {
  if (arg instanceof Error) {
    let msg = `${arg.name}: ${arg.message}`;
    if (arg.stack) msg += `
${arg.stack.replace(`${arg.toString()}
`, "")}`;
    if (arg.cause) msg += `
Caused by: ${stringify(arg.cause)}`;
    return msg;
  }
  if (typeof arg === "object") {
    return JSON.stringify(arg, null, 4);
  }
  if (Array.isArray(arg)) {
    return arg.map((a) => stringify(a)).join(", ");
  }
  return arg.toString();
};
var colors = {
  amethyst: 10053324,
  aqua: 1752220,
  blue: 3447003,
  blurple: 5793266,
  darkAqua: 1146986,
  darkBlue: 2123412,
  darkButNotBlack: 2895667,
  darkGold: 12745742,
  darkGreen: 2067276,
  darkGrey: 9936031,
  darkNavy: 2899536,
  darkOrange: 11027200,
  darkPurple: 7419530,
  darkRed: 10038562,
  darkVividPink: 11342935,
  darkerGrey: 8359053,
  default: 0,
  fuchsia: 15418782,
  gold: 15844367,
  green: 5763719,
  grey: 9807270,
  greyple: 10070709,
  lightGrey: 12370112,
  luminousVividPink: 15277667,
  navy: 3426654,
  notQuiteBlack: 2303786,
  orange: 15105570,
  purple: 10181046,
  red: 15548997,
  white: 16777215,
  yellow: 16705372
};
var uuid = v4;
var randomId = (length, mode = "both") => {
  const letters = "ABCDEFGHIJKLMNOPQRSTUVWXYZ", numbers = "0123456789";
  let charset = "", out = "";
  switch (mode) {
    case "letters":
      charset = letters + letters.toLowerCase();
      break;
    case "lettersLowerCase":
      charset = letters.toLowerCase();
      break;
    case "lettersUppercase":
      charset = letters;
      break;
    case "numbers":
      charset = numbers;
      break;
    case "both":
      charset = letters + letters.toLowerCase() + numbers;
      break;
    case "bothUpperCase":
      charset = letters + numbers;
      break;
    case "bothLowerCase":
      charset = letters.toLowerCase() + numbers;
      break;
    default:
      charset = mode;
      break;
  }
  for (let i = 0; i < length; i++) out += charset.charAt(Math.floor(Math.random() * charset.length));
  return out;
};
var highlight = (str, color) => {
  for (const match of str.match(/(\[[^[{}\]]*\]|\([^()]*\)|^[A-Z\d\s]+:|(?:https?:\/\/)[a-z0-9_\-\.]*[a-z0-9_\-]{1,}\.[a-z]{2,}(?:\?(?:\w+=\w+&?)*)?|(?:[a-z-.+]+?:\/\/)(?:[^/:@?&\\](?::[^\/:@?&\\])?@)?[^/:@?&\\]+\.[a-z]{2,})(?:\?(?:\w+=\w+&?)*)?/img) ?? [])
    str = str.replace(match, color(match));
  return str;
};
var src_default = {
  isTypescript,
  sha256,
  md5,
  hex,
  base64,
  binary,
  ascii,
  latin1,
  decode,
  plural,
  capitalize,
  crop,
  remove,
  escape,
  first,
  last,
  random,
  get,
  groupBy,
  group,
  stringify,
  colors,
  uuid,
  randomId,
  highlight
};
export {
  ascii,
  base64,
  binary,
  bytes,
  capitalize,
  colors,
  crop,
  decode,
  src_default as default,
  escape,
  first,
  get,
  group,
  groupBy,
  hex,
  highlight,
  isEven,
  isNumber,
  isOdd,
  isTypescript,
  last,
  latin1,
  md5,
  moment,
  plural,
  random,
  randomId,
  remove,
  sha256,
  stringify,
  uuid
};

if (module.exports.default) {
  Object.assign(module.exports.default, module.exports);
  module.exports = module.exports.default;
  delete module.exports.default;
}
//# sourceMappingURL=index.mjs.map